# arpes.plotting package

## Subpackages

  -   - [arpes.plotting.qt\_tool package](arpes.plotting.qt_tool)
        
          -   - [Submodules](arpes.plotting.qt_tool#submodules)
                
                  - [arpes.plotting.qt\_tool.AxisInfoWidget
                    module](arpes.plotting.qt_tool.AxisInfoWidget)
                  - [arpes.plotting.qt\_tool.BinningInfoWidget
                    module](arpes.plotting.qt_tool.BinningInfoWidget)
                  - [arpes.plotting.qt\_tool.DataArrayImageView
                    module](arpes.plotting.qt_tool.DataArrayImageView)
                  - [arpes.plotting.qt\_tool.HelpDialog
                    module](arpes.plotting.qt_tool.HelpDialog)
                  - [arpes.plotting.qt\_tool.utils
                    module](arpes.plotting.qt_tool.utils)
        
          - [Module
            contents](arpes.plotting.qt_tool#module-arpes.plotting.qt_tool)

## Submodules

  - [arpes.plotting.annotations module](arpes.plotting.annotations)
  - [arpes.plotting.band\_tool module](arpes.plotting.band_tool)
  - [arpes.plotting.bands module](arpes.plotting.bands)
  - [arpes.plotting.basic module](arpes.plotting.basic)
  - [arpes.plotting.bz module](arpes.plotting.bz)
  - [arpes.plotting.comparison\_tool
    module](arpes.plotting.comparison_tool)
  - [arpes.plotting.curvature\_tool
    module](arpes.plotting.curvature_tool)
  - [arpes.plotting.dispersion module](arpes.plotting.dispersion)
  - [arpes.plotting.dos module](arpes.plotting.dos)
  - [arpes.plotting.dyn\_tool module](arpes.plotting.dyn_tool)
  - [arpes.plotting.false\_color module](arpes.plotting.false_color)
  - [arpes.plotting.fermi\_edge module](arpes.plotting.fermi_edge)
  - [arpes.plotting.fermi\_surface module](arpes.plotting.fermi_surface)
  - [arpes.plotting.fit\_inspection\_tool
    module](arpes.plotting.fit_inspection_tool)
  - [arpes.plotting.interactive module](arpes.plotting.interactive)
  - [arpes.plotting.interactive\_utils
    module](arpes.plotting.interactive_utils)
  - [arpes.plotting.mask\_tool module](arpes.plotting.mask_tool)
  - [arpes.plotting.movie module](arpes.plotting.movie)
  - [arpes.plotting.parameter module](arpes.plotting.parameter)
  - [arpes.plotting.path\_tool module](arpes.plotting.path_tool)
  - [arpes.plotting.spatial module](arpes.plotting.spatial)
  - [arpes.plotting.spin module](arpes.plotting.spin)
  - [arpes.plotting.stack\_plot module](arpes.plotting.stack_plot)
  - [arpes.plotting.tarpes module](arpes.plotting.tarpes)
  - [arpes.plotting.tof module](arpes.plotting.tof)
  - [arpes.plotting.utils module](arpes.plotting.utils)
  - [arpes.plotting.visualize\_3d module](arpes.plotting.visualize_3d)

## Module contents
